California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 004 - WAITING PERIOD AND PARENTAL NOTIFICATION BEFORE TERMINATION OF MINOR'S PREGNANCY. INITIATIVE CONSTITUTIONAL AMENDMENT. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1276142 | CAMPAIGN FOR TEEN SAFETY - NO ON 4 - PLANNED PARENTHOOD AFFILIATES OF CALIFORNIA | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1298466 | FRIENDS OF SARAH, YES ON PROP 4, THE PARENTAL OR ALTERNATIVE FAMILY MEMBER NOTIFICATION LAW, MAJOR FUNDING BY DON SEBASTIANI & JIM HOLMAN & OTHERS TO REFORM CHILD PROTECTION LAWS IN CA | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1307489 | NO ON PROPOSITION 4 - CAMPAIGN FOR TEEN HEALTH AND SAFETY, A PROJECT OF AMERICAN CIVIL LIBERTIES UNION OF NORTHERN CALIFORNIA | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1313055 | NO ON 4 SPONSORED BY ASIAN COMMUNITIES FOR REPRODUCTIVE JUSTICE | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1312996 | CAMPAIGN AGAINST PROPOSITIONS 4, 6, 8, 9, & FOR PROPOSITION 5 CALIFORNIANS FOR JUSTICE EDUCATION FUND | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1311419 | VOTE NO ON PROPS. 4 & 8, SPONSORED BY FEMINIST MAJORITY FOUNDATION | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1310995 | CREDO VICTORY FUND TO DEFEAT PROP. 4 | OPPOSE